Learn R Programming

mlr3misc (version 0.22.0)

register_namespace_callback: Registers a Callback on Namespace load/unLoad Events

Description

Register a function callback to be called after a namespace is loaded. Calls callback once if the namespace has already been loaded before and also adds an unload-hook that removes the load hook.

Usage

register_namespace_callback(pkgname, namespace, callback)

Value

NULL.

Arguments

pkgname

(character(1))
Name of the package which registers the callback.

namespace

(character(1))
Namespace to react on.

callback

(function())
Function to call on namespace load. The callback is invoked without arguments, so it can be defined as function() or function(...). Any arguments passed by the hook caller (e.g. package and lib_path from pkgload) are discarded.