Frequently used helper functions and assertions used in 'mlr3' and its companion packages. Comes with helper functions for functional programming, for printing, to work with 'data.table', as well as some generally useful 'R6' classes. This package also supersedes the package 'BBmisc'.
Maintainer: Michel Lang [email protected] (ORCID)
Authors:
Patrick Schratz [email protected] (ORCID)
Useful links: